Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
func New(options ...Option) alertcenter.IAlertSender
Types ¶
type Option ¶
type Option func(*Sender)
func WithSenderEmail ¶
func WithSenderName ¶
func WithUsernamePassword ¶
type Sender ¶
type Sender struct {
// Host represents the host of the SMTP server.
Host string
// Port represents the port of the SMTP server.
Port int
// Username is the username to use to authenticate to the SMTP server
Username string
// Password is the password to use to authenticate to the SMTP server
Password string
// SenderName is the email sender's name
SenderName string
// SenderEmail is the email sender's email address
SenderEmail string
// bypass the verification of the server's certificate chain and host name
TLSInsecureSkipVerify bool
}
Click to show internal directories.
Click to hide internal directories.